@@ -1,14 +1,27 @@
 import enum
 import inspect
-from typing import Any, Callable, Dict, List, Mapping, Type, cast
+from typing import Any, Callable, Dict, List, Mapping, Optional, Type, cast
 
-from .exceptions import MissingArgumentsAnnotationsError, UnsupportedTypeError
+from typing_extensions import Annotated, get_args, get_origin
+
+from .exceptions import (
+    MissingArgumentsAnnotationsError,
+    MultipleStrawberryArgumentsError,
+    UnsupportedTypeError,
+)
 from .scalars import is_scalar
 from .types.type_resolver import resolve_type
 from .types.types import ArgumentDefinition, undefined
 from .utils.str_converters import to_camel_case
 
 
+class StrawberryArgument:
+    description: Optional[str]
+
+    def __init__(self, description: Optional[str] = None):
+        self.description = description
+
+
 def get_arguments_from_annotations(
     annotations: Any, parameters: Mapping[str, inspect.Parameter], origin: Any
 ) -> List[ArgumentDefinition]:
@@ -26,10 +39,31 @@ def get_arguments_from_annotations(
             origin_name=name,
             name=to_camel_case(name),
             origin=origin,
-            type=annotation,
             default_value=default_value,
         )
 
+        if get_origin(annotation) is Annotated:
+            annotated_args = get_args(annotation)
+
+            # The first argument to Annotated is always the underlying type
+            argument_definition.type = annotated_args[0]
+
+            argument_metadata = None
+            # Find any instances of StrawberryArgument in the other Annotated args,
+            # raising an exception if there are multiple StrawberryArguments
+            for arg in annotated_args[1:]:
+                if isinstance(arg, StrawberryArgument):
+                    if argument_metadata is not None:
+                        raise MultipleStrawberryArgumentsError(
+                            field_name=origin.__name__, argument_name=name
+                        )
+                    argument_metadata = arg
+
+            if argument_metadata is not None:
+                argument_definition.description = argument_metadata.description
+        else:
+            argument_definition.type = annotation
+
         arguments.append(argument_definition)
 
         resolve_type(argument_definition)
@@ -67,7 +101,7 @@ class _Unset:
         return False
 
 
-UNSET = _Unset()
+UNSET: Any = _Unset()
 
 
 def is_unset(value: Any) -> bool:
@@ -111,7 +145,8 @@ def convert_argument(value: Any, argument_definition: ArgumentDefinition) -> Any
 
 
 def convert_arguments(
-    value: Dict[str, Any], arguments: List[ArgumentDefinition],
+    value: Dict[str, Any],
+    arguments: List[ArgumentDefinition],
 ) -> Dict[str, Any]:
     """Converts a nested dictionary to a dictionary of actual types.
 
@@ -131,3 +166,7 @@ def convert_arguments(
             kwargs[origin_name] = convert_argument(current_value, argument)
 
     return kwargs
+
+
+def argument(description: Optional[str] = None) -> StrawberryArgument:
+    return StrawberryArgument(description=description)
