@@ -1,13 +1,15 @@
 import asyncio
 import typing
 
-from graphql import GraphQLError
-from graphql.error import format_error as format_graphql_error
 from starlette.requests import Request
 from starlette.types import Receive, Scope, Send
 from starlette.websockets import WebSocket, WebSocketState
+
+from graphql import GraphQLError
+from graphql.error import format_error as format_graphql_error
+
 from strawberry.http import GraphQLHTTPResponse, process_result
-from strawberry.schema import ExecutionResult
+from strawberry.types import ExecutionResult
 
 from ..schema import BaseSchema
 from ..utils.debug import pretty_print_graphql_operation
@@ -51,7 +53,9 @@ class GraphQL:
     async def get_root_value(self, request: Request) -> typing.Optional[typing.Any]:
         return None
 
-    async def get_context(self, request: Request) -> typing.Optional[typing.Any]:
+    async def get_context(
+        self, request: typing.Union[Request, WebSocket]
+    ) -> typing.Optional[typing.Any]:
         return {"request": request}
 
     async def handle_keep_alive(self, websocket):
@@ -96,7 +100,7 @@ class GraphQL:
         if self.debug:
             pretty_print_graphql_operation(operation_name, query, variables)
 
-        context = {"websocket": websocket}
+        context = await self.get_context(websocket)
 
         data = await self.schema.subscribe(
             query,
